greybus: bundle: s/gb_interface/gb_bundle/g

Rename struct gb_interface to struct gb_bundle

It's a lot of renaming, some structures got renamed and also some
fields, but the goal was to rename things to make sense with the new
naming of how the system is put together in the 'driver model' view.

Reviewed-by: Alex Elder <elder@linaro.org>
Signed-off-by: Greg Kroah-Hartman <greg@kroah.com>
diff --git a/drivers/staging/greybus/greybus_manifest.h b/drivers/staging/greybus/greybus_manifest.h
index deff5c7..398630c 100644
--- a/drivers/staging/greybus/greybus_manifest.h
+++ b/drivers/staging/greybus/greybus_manifest.h
@@ -106,13 +106,13 @@
 };
 
 /*
  * A CPort descriptor indicates the id of the interface within the
  * module it's associated with, along with the CPort id used to
  * address the CPort.  The protocol id defines the format of messages
  * exchanged using the CPort.
  */
 struct greybus_descriptor_cport {
-	__u8	interface;
+	__u8	bundle;
 	__le16	id;
 	__u8	protocol_id;	/* enum greybus_protocol */
 };
@@ -106,13 +106,13 @@
 
 /*
- * A CPort descriptor indicates the id of the interface within the
+ * A CPort descriptor indicates the id of the bundle within the
  * module it's associated with, along with the CPort id used to
  * address the CPort.  The protocol id defines the format of messages